#!/usr/bin/env node
global.navigator={};
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const FileLoader_1 = require("./FileLoader");
const ReactQueryHookGenerator_1 = require("./ReactQueryHookGenerator");
const SchemaParser_1 = require("./SchemaParser");
const TypesGenerator_1 = require("./TypesGenerator");
const helpers_1 = require("./helpers");
async function main() {
    const loader = new FileLoader_1.FileLoader('document.yaml');
    const rawDocument = await loader.load();
    const parser = new SchemaParser_1.SchemaParser(rawDocument, loader);
    const document = await parser.parse();
    const paths = document.paths;
    const groupedOperations = (0, helpers_1.groupOperations)((0, helpers_1.flattenPaths)(paths));
    const groups = Object.keys(groupedOperations);
    const hookGen = new ReactQueryHookGenerator_1.ReactQueryHookGenerator({
        overridePolicy: 'override',
    });
    const typeGen = new TypesGenerator_1.TypesGenerator({
        overridePolicy: 'override',
    });
    await Promise.all([
        ...groups.map(group => {
            hookGen.generate(group, groupedOperations[group]);
        }),
        ...groups.map(group => {
            typeGen.generate(group, groupedOperations[group]);
        }),
    ]);
}
main().catch(console.error);
